FrameProcessingResult class
Constructors
-
FrameProcessingResult({required int fps, required int frameCount, required List<
String> framePaths})
Properties
- fps → int
-
final
- frameCount → int
-
final
-
framePaths
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited